==> preleganto-0.1.1.tgz: package/lib/presentation/control.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

(function () {
    function select(selector) {
        return document.querySelector(selector);
    }

    function selectAll(selector) {
        return Array.from(document.querySelectorAll(selector));
    }

    var LEFT = 37;
    var UP = 38;
    var RIGHT = 39;
    var DOWN = 40;
    var SPACE = 32;
    var ENTER = 13;

    var CONTROL_KEYS = [LEFT, UP, RIGHT, DOWN, SPACE, ENTER];

    function mapKey(e) {
        if (e.keyCode === 0) {
            return e.charCode;
        } else {
            return e.keyCode;
        }
    }

    var Preleganto = function () {
        function Preleganto() {
            _classCallCheck(this, Preleganto);

            var metadataScript = select('script[type="text/preleganto-metadata"]');

            if (metadataScript) {
                this._metadata = JSON.parse(metadataScript.textContent);
            } else {
                console.warn('Cannot find Preleganto metadata. The presentation will run in limited mode.');
                this._metadata = {
                    ratio: '16:10'
                };
            }

            this._slides = selectAll('.preleganto-slide');

            this._attachEventHandlers();
            this._setSlidesSize([window.innerWidth, window.innerHeight]);

            if (/view-\d+/.test(window.location.hash)) {
                this.goTo(Number(window.location.hash.match(/view-(\d+)/)[1]) - 1);
            } else {
                this._current = 0;
                window.location.hash = 'view-1';
            }
        }

        _createClass(Preleganto, [{
            key: 'goTo',
            value: function goTo(index) {
                if (index >= this._slides.length) {
                    this._current = this._slides.length - 1;
                } else if (index < 0) {
                    this._current = 0;
                } else {
                    this._current = index;
                }

                window.scrollTo(0, this._slides[this._current].offsetTop);
                window.location.hash = 'view-' + (this._current + 1);
                return this._current;
            }
        }, {
            key: 'previous',
            value: function previous() {
                return this.goTo(this._current - 1);
            }
        }, {
            key: 'next',
            value: function next() {
                return this.goTo(this._current + 1);
            }
        }, {
            key: 'getCurrent',
            value: function getCurrent() {
                return this._current;
            }
        }, {
            key: 'getTotal',
            value: function getTotal() {
                return this._slides.length;
            }
        }, {
            key: 'getMetadata',
            value: function getMetadata() {
                return this._metadata;
            }
        }, {
            key: 'parseRatio',
            value: function parseRatio() {
                return [Number(this._metadata.ratio.split(':')[0]), Number(this._metadata.ratio.split(':')[1])];
            }
        }, {
            key: '_attachEventHandlers',
            value: function _attachEventHandlers() {
                var _this = this;

                // resize slides when window changed its size
                window.addEventListener('resize', function (ev) {
                    _this._setSlidesSize([ev.target.innerWidth, ev.target.innerHeight]);
                    _this.goTo(_this._current);
                });

                // disable control keys
                window.addEventListener('keypress', function (ev) {
                    if (CONTROL_KEYS.indexOf(mapKey(ev)) !== -1) {
                        ev.preventDefault();
                    }
                });

                // attach control keys' handlers
                window.addEventListener('keyup', function (ev) {
                    switch (mapKey(ev)) {
                        case LEFT:
                        case UP:
                            _this.previous();
                            break;
                        case RIGHT:
                        case DOWN:
                        case SPACE:
                        case ENTER:
                            _this.next();
                            break;
                    }
                });
            }
        }, {
            key: '_setSlidesSize',
            value: function _setSlidesSize(dimensions) {
                var ratio = this.parseRatio();
                var width = Math.min(ratio[0] / ratio[1] * dimensions[1], dimensions[0]);
                var height = dimensions[1];

                this._slides.forEach(function (node) {
                    node.style.width = width + 'px';
                    node.style.height = height + 'px';
                });
            }
        }]);

        return Preleganto;
    }();

    window.preleganto = new Preleganto();
})();

==> preleganto-0.1.2.tgz: package/lib/presentation/control.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

(function () {

    function select(selector) {
        return document.querySelector(selector);
    }

    function selectAll(selector) {
        return Array.from(document.querySelectorAll(selector));
    }

    var LEFT = 37;
    var UP = 38;
    var RIGHT = 39;
    var DOWN = 40;
    var SPACE = 32;
    var ENTER = 13;

    var CONTROL_KEYS = [LEFT, UP, RIGHT, DOWN, SPACE, ENTER];

    function mapKey(e) {
        if (e.keyCode === 0) {
            return e.charCode;
        } else {
            return e.keyCode;
        }
    }

    var Preleganto = function () {
        function Preleganto() {
            _classCallCheck(this, Preleganto);

            var metadataScript = select('script[type="text/preleganto-metadata"]');

            if (metadataScript) {
                this._metadata = JSON.parse(metadataScript.textContent);
            } else {
                console.warn('Cannot find Preleganto metadata. The presentation will run in limited mode.');
                this._metadata = {
                    ratio: '16:10'
                };
            }

            this._slides = selectAll('.preleganto-slide');

            this._actionQueue = [];
            this._socket = new WebSocket('ws://' + window.location.host);

            if (/view-\d+/.test(window.location.hash)) {
                this.goTo(Number(window.location.hash.match(/view-(\d+)/)[1]) - 1, false);
            } else {
                this._current = 0;
                window.location.hash = 'view-1';
            }

            this._attachEventHandlers();
            this._setSlidesSize([window.innerWidth, window.innerHeight]);
        }

        _createClass(Preleganto, [{
            key: 'goTo',
            value: function goTo(index) {
                var notify = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

                if (index >= this._slides.length) {
                    this._current = this._slides.length - 1;
                } else if (index < 0) {
                    this._current = 0;
                } else {
                    this._current = index;
                }

                if (notify) {
                    var action = { name: 'goTo', index: index };
                    if (this._socket.readyState === WebSocket.OPEN) {
                        this._send(action);
                    } else {
                        this._actionQueue.push(action);
                    }
                }

                window.scrollTo(0, this._slides[this._current].offsetTop);
                window.location.hash = 'view-' + (this._current + 1);
                return this._current;
            }
        }, {
            key: 'previous',
            value: function previous() {
                return this.goTo(this._current - 1);
            }
        }, {
            key: 'next',
            value: function next() {
                return this.goTo(this._current + 1);
            }
        }, {
            key: 'getCurrent',
            value: function getCurrent() {
                return this._current;
            }
        }, {
            key: 'getTotal',
            value: function getTotal() {
                return this._slides.length;
            }
        }, {
            key: 'getMetadata',
            value: function getMetadata() {
                return this._metadata;
            }
        }, {
            key: 'parseRatio',
            value: function parseRatio() {
                return [Number(this._metadata.ratio.split(':')[0]), Number(this._metadata.ratio.split(':')[1])];
            }
        }, {
            key: '_send',
            value: function _send(action) {
                this._socket.send(JSON.stringify(action));
            }
        }, {
            key: '_attachEventHandlers',
            value: function _attachEventHandlers() {
                var _this = this;

                // resize slides when window changed its size
                window.addEventListener('resize', function (ev) {
                    _this._setSlidesSize([ev.target.innerWidth, ev.target.innerHeight]);
                    _this.goTo(_this._current, false);
                });

                // disable control keys
                window.addEventListener('keypress', function (ev) {
                    if (CONTROL_KEYS.indexOf(mapKey(ev)) !== -1) {
                        ev.preventDefault();
                    }
                });

                // attach control keys' handlers
                window.addEventListener('keyup', function (ev) {
                    switch (mapKey(ev)) {
                        case LEFT:
                        case UP:
                            _this.previous();
                            break;
                        case RIGHT:
                        case DOWN:
                        case SPACE:
                        case ENTER:
                            _this.next();
                            break;
                    }
                });

                this._socket.onopen = function () {
                    _this._send({ name: 'sync' });
                    _this._actionQueue.forEach(function (action) {
                        return _this._send(action);
                    });
                };

                this._socket.onmessage = function (event) {
                    var action = JSON.parse(String(event.data));
                    switch (action.name) {
                        case 'goTo':
                            _this.goTo(action.index, false);
                            break;
                        case 'sync':
                            _this._send({ name: 'goTo', index: _this._current });
                            break;
                        case 'reload':
                            // force browser to reload presentation from server
                            window.location.reload(true);
                            break;
                    }
                };
            }
        }, {
            key: '_setSlidesSize',
            value: function _setSlidesSize(dimensions) {
                var ratio = this.parseRatio();
                var width = Math.min(ratio[0] / ratio[1] * dimensions[1], dimensions[0]);
                var height = dimensions[1];

                this._slides.forEach(function (node) {
                    node.style.width = width + 'px';
                    node.style.height = height + 'px';
                });
            }
        }]);

        return Preleganto;
    }();

    window.preleganto = new Preleganto();
})();
